Flask-OpenHeart
===============

`Flask-OpenHeart <https://github.com/woodrowbarlow/flask-openheart>`_ adds `OpenHeart <https://openheart.fyi>`_
support to `Flask <https://flask.palletsprojects.com>`_ applications, providing a simple way for users to react with
emojis to Flask URLs.

.. note::

    This project is in early development. Much of the functionality does not yet behave as described.

.. toctree::
   :maxdepth: 1

   quickstart
   configuration
   examples
   public_api
   private_api
